@@ -108,7 +108,7 @@ $lang = array_merge($lang, array(
 	'MAX_AVATAR_SIZE'				=> 'Dimensions màximes dels avatars',
 	'MAX_AVATAR_SIZE_EXPLAIN'		=> 'Amplària x Alçària en píxels.',
 	'MAX_FILESIZE'					=> 'Mida màxima dels fitxers d’avatar',
-	'MAX_FILESIZE_EXPLAIN'			=> 'Per a fitxers d’avatar pujats.',
+	'MAX_FILESIZE_EXPLAIN'			=> 'Per a fitxers d’avatar pujats. Si el valor és 0, la mida del fitxer a pujar només està limitada per la configuració del PHP.',
 	'MIN_AVATAR_SIZE'				=> 'Dimensions mínimes dels avatars',
 	'MIN_AVATAR_SIZE_EXPLAIN'		=> 'Amplària x Alçària en píxels.',
 ));
