@@ -171,7 +171,7 @@ $lang = array_merge($lang, array(
 	'ROLE_FORUM_POLLS'			=> 'Accés estàndard i enquestes',
 	'ROLE_FORUM_READONLY'		=> 'Accés només de lectura',
 	'ROLE_FORUM_STANDARD'		=> 'Accés estàndard',
-	'ROLE_FORUM_NEW_MEMBER'		=> 'Nou usuari registrat',
+	'ROLE_FORUM_NEW_MEMBER'		=> 'Accés d’usuari acabat de registrar',
 	'ROLE_MOD_FULL'				=> 'Moderador complet',
 	'ROLE_MOD_QUEUE'			=> 'Moderador de cua',
 	'ROLE_MOD_SIMPLE'			=> 'Moderador simple',
@@ -181,7 +181,7 @@ $lang = array_merge($lang, array(
 	'ROLE_USER_NOAVATAR'		=> 'Sense avatar',
 	'ROLE_USER_NOPM'			=> 'Sense missatges privats',
 	'ROLE_USER_STANDARD'		=> 'Característiques estàndard',
-	'ROLE_USER_NEW_MEMBER'		=> 'Nou usuari registrat',
+	'ROLE_USER_NEW_MEMBER'		=> 'Característiques d’usuari acabat de registrar',
 
 
 	'ROLE_DESCRIPTION_ADMIN_FORUM'			=> 'Pot accedir a la gestió de fòrums i a la configuració de permisos del fòrum.',
