@@ -191,7 +191,7 @@ $lang = array_merge($lang, array(
 	'FORM_INVALID'			=> 'El formulari tramès no és vàlid. Intenteu tornar a trametre’l.',
 	'FORUM'					=> 'Fòrum',
 	'FORUMS'				=> 'Fòrums',
-	'FORUMS_MARKED'			=> 'Els fòrums seleccionats s’han marcat com a llegits.',
+	'FORUMS_MARKED'			=> 'Els fòrums s’han marcat com a llegits.',
 	'FORUM_CAT'				=> 'Categoria del fòrum',
 	'FORUM_INDEX'			=> 'Índex del fòrum',
 	'FORUM_LINK'			=> 'Enllaç del fòrum',
@@ -450,6 +450,7 @@ $lang = array_merge($lang, array(
 	'POST_TIME'				=> 'Data de l’entrada',
 	'POST_TOPIC'			=> 'Publica un nou tema',
 	'POST_UNAPPROVED'		=> 'Aquesta entrada està pendent d’aprovació',
+	'POWERED_BY'			=> 'Funciona amb %s',
 	'PREVIEW'				=> 'Previsualització',
 	'PREVIOUS'				=> 'Anterior',		// Used in pagination
 	'PREVIOUS_STEP'			=> 'Anterior',
@@ -459,6 +460,7 @@ $lang = array_merge($lang, array(
 	'PRIVATE_MESSAGING'		=> 'Missatgeria privada',
 	'PROFILE'				=> 'Tauler de control de l’usuari',
 
+	'RANK'						=> 'Rang',
 	'READING_FORUM'				=> 'Està veient temes a %s',
 	'READING_GLOBAL_ANNOUNCE'	=> 'Està llegint un avís global',
 	'READING_LINK'				=> 'Ha fet clic sobre l’enllaç del fòrum %s',
