@@ -137,7 +137,8 @@ $lang = array_merge($lang, array(
 	'CREATE_FOLDER'				=> 'Afegeix una carpeta…',
 	'CURRENT_IMAGE'				=> 'Imatge actual',
 	'CURRENT_PASSWORD'			=> 'Contrasenya actual',
-	'CURRENT_PASSWORD_EXPLAIN'	=> 'Cal que confirmeu la vostra contrasenya quan la canvieu, o canvieu la vostra adreça electrònica o nom d’usuari.',
+	'CURRENT_PASSWORD_EXPLAIN'	=> 'Cal que introdïu la vostra contrasenya quan canvieu la vostra adreça electrònica o nom d’usuari.',
+	'CURRENT_CHANGE_PASSWORD_EXPLAIN' => 'Per canviar la vostra contrasenya, adreça electrònica o nom d’usuari heu d’introduir la vostra contrasenya actual.',
 	'CUR_PASSWORD_EMPTY'		=> 'No heu introduït la vostra contrasenya actual.',
 	'CUR_PASSWORD_ERROR'		=> 'La contrasenya que heu introduït no és correcta.',
 	'CUSTOM_DATEFORMAT'			=> 'Personalitzada…',
@@ -387,6 +388,7 @@ $lang = array_merge($lang, array(
 	'RULE_ADDED'						=> 'S’ha afegit la regla correctament.',
 	'RULE_ALREADY_DEFINED'				=> 'Aquesta regla ja està definida.',
 	'RULE_DELETED'						=> 'S’ha eliminat la regla correctament.',
+	'RULE_LIMIT_REACHED'				=> 'No podeu afegir més regles de MP. Heu assolit el nombre màxim de regles.',
 	'RULE_NOT_DEFINED'					=> 'No s’ha especificat la regla correctament.',
 	'RULE_REMOVED_MESSAGE'				=> 'S’ha eliminat 1 missatge privat a causa dels filtres.',
 	'RULE_REMOVED_MESSAGES'				=> 'S’han eliminat %d missatges privats a causa dels filtres.',
